from distutils.core import setup

setup(name='draw with percentage',
      version='0.0.2',
      description='Python Library to draw with percentage',
      author='Mateusz Kołodziejczyk',
      author_email='mateusz.j.kolodziejczyk@gmail.com',
      license='MIT',
      python_requires='>=3.5'
      )
